# gen_head

[![PyPI - Version](https://img.shields.io/pypi/v/gen_head.svg)](https://pypi.org/project/gen_head)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/gen_head.svg)](https://pypi.org/project/gen_head)

-----

## Table of Contents

- [Installation](#installation)

## Installation

```console
pip install gen_head
```